==> cobalt-0.0.1-sources.jar: it/auties/whatsapp/model/message/button/ListMessageBuilder.java <==
package it.auties.whatsapp.model.message.button;

public class ListMessageBuilder {
    private java.lang.String title;
    private java.util.Optional<java.lang.String> description;
    private java.lang.String button;
    private it.auties.whatsapp.model.message.button.ListMessage.Type listType;
    private java.util.List<it.auties.whatsapp.model.button.misc.ButtonSection> sections;
    private java.util.Optional<it.auties.whatsapp.model.info.ProductListInfo> productListInfo;
    private java.util.Optional<java.lang.String> footer;
    private java.util.Optional<it.auties.whatsapp.model.info.ContextInfo> contextInfo;

    public ListMessageBuilder() {
        title = null;
        description = java.util.Optional.empty();
        button = null;
        listType = null;
        sections = new java.util.ArrayList<it.auties.whatsapp.model.button.misc.ButtonSection>();
        productListInfo = java.util.Optional.empty();
        footer = java.util.Optional.empty();
        contextInfo = java.util.Optional.empty();
    }

    public ListMessageBuilder title(java.lang.String title) {
        this.title = title;
        return this;
    }
    public ListMessageBuilder description(java.util.Optional<java.lang.String> description) {
        this.description = description;
        return this;
    }
    public ListMessageBuilder description(java.lang.String description) {
        this.description = java.util.Optional.ofNullable(description);
        return this;
    }
    public ListMessageBuilder button(java.lang.String button) {
        this.button = button;
        return this;
    }
    public ListMessageBuilder listType(it.auties.whatsapp.model.message.button.ListMessage.Type listType) {
        this.listType = listType;
        return this;
    }
    public ListMessageBuilder sections(java.util.List<it.auties.whatsapp.model.button.misc.ButtonSection> sections) {
        this.sections = sections;
        return this;
    }
    public ListMessageBuilder productListInfo(java.util.Optional<it.auties.whatsapp.model.info.ProductListInfo> productListInfo) {
        this.productListInfo = productListInfo;
        return this;
    }
    public ListMessageBuilder productListInfo(it.auties.whatsapp.model.info.ProductListInfo productListInfo) {
        this.productListInfo = java.util.Optional.ofNullable(productListInfo);
        return this;
    }
    public ListMessageBuilder footer(java.util.Optional<java.lang.String> footer) {
        this.footer = footer;
        return this;
    }
    public ListMessageBuilder footer(java.lang.String footer) {
        this.footer = java.util.Optional.ofNullable(footer);
        return this;
    }
    public ListMessageBuilder contextInfo(java.util.Optional<it.auties.whatsapp.model.info.ContextInfo> contextInfo) {
        this.contextInfo = contextInfo;
        return this;
    }
    public ListMessageBuilder contextInfo(it.auties.whatsapp.model.info.ContextInfo contextInfo) {
        this.contextInfo = java.util.Optional.ofNullable(contextInfo);
        return this;
    }

    public it.auties.whatsapp.model.message.button.ListMessage build() {
        return new it.auties.whatsapp.model.message.button.ListMessage(title, description, button, listType, sections, productListInfo, footer, contextInfo);
    }
}

==> cobalt-0.0.3-sources.jar: it/auties/whatsapp/model/message/button/ListMessageBuilder.java <==
package it.auties.whatsapp.model.message.button;

public class ListMessageBuilder {
    private java.lang.String title;
    private java.lang.String description;
    private java.lang.String button;
    private it.auties.whatsapp.model.message.button.ListMessage.Type listType;
    private java.util.List<it.auties.whatsapp.model.button.misc.ButtonSection> sections;
    private it.auties.whatsapp.model.info.ProductListInfo productListInfo;
    private java.lang.String footer;
    private it.auties.whatsapp.model.info.ContextInfo contextInfo;

    public ListMessageBuilder() {
        title = null;
        description = null;
        button = null;
        listType = null;
        sections = new java.util.ArrayList<it.auties.whatsapp.model.button.misc.ButtonSection>();
        productListInfo = null;
        footer = null;
        contextInfo = null;
    }

    public ListMessageBuilder title(java.lang.String title) {
        this.title = title;
        return this;
    }
    public ListMessageBuilder description(java.lang.String description) {
        this.description = description;
        return this;
    }
    public ListMessageBuilder button(java.lang.String button) {
        this.button = button;
        return this;
    }
    public ListMessageBuilder listType(it.auties.whatsapp.model.message.button.ListMessage.Type listType) {
        this.listType = listType;
        return this;
    }
    public ListMessageBuilder sections(java.util.List<it.auties.whatsapp.model.button.misc.ButtonSection> sections) {
        this.sections = sections;
        return this;
    }
    public ListMessageBuilder productListInfo(it.auties.whatsapp.model.info.ProductListInfo productListInfo) {
        this.productListInfo = productListInfo;
        return this;
    }
    public ListMessageBuilder footer(java.lang.String footer) {
        this.footer = footer;
        return this;
    }
    public ListMessageBuilder contextInfo(it.auties.whatsapp.model.info.ContextInfo contextInfo) {
        this.contextInfo = contextInfo;
        return this;
    }

    public it.auties.whatsapp.model.message.button.ListMessage build() {
        return new it.auties.whatsapp.model.message.button.ListMessage(title, description, button, listType, sections, productListInfo, footer, contextInfo);
    }
}
